@@ -38,6 +38,7 @@
 
   
    HISTORY: 
+   2005-06-16 : 1.7.1	   - PDFs are protected during creation by file mode 000
    2005-03-07 : 1.7.0a
    2005-03-01 : 1.7.0      - call of GhostScript from a non-privileged child process,
                              no more additional programs in the call of GhostScript,
@@ -509,7 +510,8 @@ int main(int argc, char *argv[]) {
       log_event(CPERROR, "failed to set UID for current user", passwd->pw_name);
     else 
       log_event(CPDEBUG, "UID set for current user", passwd->pw_name);
-
+     
+    umask(0777);
     size=system(gscall);
     snprintf(title,BUFSIZE,"%d",size);
     log_event(CPDEBUG, "ghostscript has finished", title);
